#
# spec file for package telepathy-qt5
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define         libname libtelepathy-qt5
%define         soversion         0
%define         service_soversion 1
# SLE12 does not have farstream support in ppc64le but openSUSE Factory and Ports does
%if 0%{?suse_version} == 1315 && !0%{?is_opensuse}
%ifnarch ppc64le
%define with_farstream 1
%endif
%else
%define with_farstream 1
%endif
Name:           telepathy-qt5
Version:        0.9.8
Release:        bp153.1.52
Summary:        Qt5 bindings for the Telepathy Library
License:        LGPL-2.1-or-later
Group:          Development/Tools/Other
URL:            https://telepathy.freedesktop.org/
Source:         https://telepathy.freedesktop.org/releases/telepathy-qt/telepathy-qt-%{version}.tar.gz
Source1:        baselibs.conf
BuildRequires:  cmake >= 3.5
BuildRequires:  fdupes
# FIXME patch, or make upstream look for qhelpgenerator-qt5 first
#BuildRequires:  libqt5-qttools-devel
#BuildRequires:  doxygen
BuildRequires:  libxml2-devel
BuildRequires:  pkgconfig
BuildRequires:  python3-devel
BuildRequires:  cmake(Qt5Core)
BuildRequires:  cmake(Qt5DBus)
BuildRequires:  cmake(Qt5Gui)
BuildRequires:  cmake(Qt5Network)
BuildRequires:  cmake(Qt5Test)
BuildRequires:  cmake(Qt5Widgets)
BuildRequires:  cmake(Qt5Xml)
BuildRequires:  pkgconfig(gstreamer-1.0)
BuildRequires:  pkgconfig(gstreamer-plugins-base-1.0)
BuildRequires:  pkgconfig(telepathy-glib)
%if 0%{?with_farstream}
BuildRequires:  pkgconfig(farstream-0.2)
BuildRequires:  pkgconfig(telepathy-farstream)
%endif

%description
Telepathy-Qt5 is a high-level binding for Telepathy, similar to telepathy-glib but for Qt 5.

%package -n %{libname}-%{soversion}
Summary:        Qt5 bindings for the Telepathy Library
Group:          Development/Tools/Other

%description -n %{libname}-%{soversion}
Telepathy-Qt5 is a high-level binding for Telepathy, similar to telepathy-glib but for Qt 5.

%package -n %{libname}-service%{service_soversion}
Summary:        Qt5 bindings for the Telepathy Library
Group:          Development/Tools/Other

%description -n %{libname}-service%{service_soversion}
Service library for the Qt5 telepathy binding.

%if 0%{?with_farstream}
%package -n %{libname}-farstream%{soversion}
Summary:        Qt5 bindings for the Telepathy Library
Group:          Development/Tools/Other

%description -n %{libname}-farstream%{soversion}
Telepathy-Qt5-farstream is a high-level binding for Telepathy, similar to telepathy-glib but for Qt 5.
%endif

%package devel
Summary:        Header files, libraries and development documentation for %{name}
Group:          Development/Libraries/C and C++
Requires:       %{libname}-%{soversion} = %{version}
Requires:       %{libname}-service%{service_soversion} = %{version}
Requires:       pkgconfig(gstreamer-1.0)
Requires:       pkgconfig(gstreamer-plugins-base-1.0)
Provides:       %{name}-service-devel-static = %{version}
%if 0%{?with_farstream}
Requires:       %{libname}-farstream%{soversion} = %{version}
%endif

%description devel
This package contains the header files, static libraries and development documentation for %{name}. If you like to develop programs using %{name}, you will need to install %{name}-devel.

%prep
%setup -q -n telepathy-qt-%{version}

%build
if [ %{_lib} = lib64 ]; then
  EXTRA_FLAGS="$EXTRA_FLAGS -DLIB_SUFFIX=64"
fi
mkdir build
cd build
cmake -DCMAKE_BUILD_TYPE=release \
      -DCMAKE_INSTALL_PREFIX=/usr \
      -DCMAKE_C_FLAGS="%{optflags}" \
      -DCMAKE_CXX_FLAGS="%{optflags}" \
      -DENABLE_TESTS=FALSE \
      -DENABLE_EXAMPLES=FALSE \
      -DENABLE_FARSIGHT=FALSE \
%if 0%{?with_farstream}
      -DENABLE_FARSTREAM=TRUE \
%endif
      -DDISABLE_WERROR=TRUE \
      -DDESIRED_QT_VERSION=5 $EXTRA_FLAGS ..

make %{?_smp_mflags}

%install
%make_install -C build
%fdupes %{buildroot}

%post -n %{libname}-%{soversion} -p /sbin/ldconfig
%postun -n %{libname}-%{soversion} -p /sbin/ldconfig
%post -n %{libname}-service%{service_soversion} -p /sbin/ldconfig
%postun -n %{libname}-service%{service_soversion} -p /sbin/ldconfig

%if 0%{?with_farstream}
%post -n %{libname}-farstream%{soversion} -p /sbin/ldconfig
%postun -n %{libname}-farstream%{soversion} -p /sbin/ldconfig
%endif

%files -n %{libname}-%{soversion}
%license COPYING
%{_libdir}/libtelepathy-qt5.so.*

%files -n %{libname}-service%{service_soversion}
%license COPYING
%{_libdir}/libtelepathy-qt5-service.so.*

%if 0%{?with_farstream}
%files -n %{libname}-farstream%{soversion}
%license COPYING
%{_libdir}/libtelepathy-qt5-farstream.so.*
%endif

%files devel
%license COPYING
%doc AUTHORS ChangeLog README HACKING NEWS
%{_includedir}/telepathy-qt5/
%{_libdir}/libtelepathy-qt5*.so
%{_libdir}/pkgconfig/TelepathyQt5*.pc
%{_libdir}/cmake/TelepathyQt5*/

%changelog
* Thu Mar 12 2020 Christophe Giboudeaux <christophe@krop.fr>
- Remove the unneeded dbus-python build dependency.
* Sun Jan 19 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 0.9.8:
  * Python3 port
  * Improved the documentation generation
  * Reworked exported CMake targets
  * GNUInstallDirs used to simplify packaging
  * Added constructor from initializer_list to generated Telepathy types
  * Added a getter for 'silent' Message flag
  * Adjusted BaseChannelTextType API
  * Added BaseConnectionContactGroupsInterface
  * Fixed BaseDebug API
  * Added BaseConnection::getExistingChannel()
  * Fixed work with threaded QtDBus
  * Omit parts with non-empty 'interface' key value for Message::text()
  * A lot of fixes in tests
  * fd.o #40008: Fix dependencies lookup (we used to prefer system-wide libs)
* Fri Sep  2 2016 buschmann23@opensuse.org
- add libtelepathy-qt5-service0 to baselibs.conf
* Fri Sep  2 2016 buschmann23@opensuse.org
- Update to 0.9.7
  - Dependencies:
  * CMake minimum version bumped to 2.8.12.
  - Enhancements:
  * Various documentation fixes and improvements.
  * Service library is now a shared library with own ABI versioning.
  * Implemented BaseConnectionContactsInterface::getContactByID().
  * Reimplemented BaseChannelGroupInterface class
  - Has new future-proof API.
  - Has documentation for all methods.
  - Flags Properties and MembersChangedDetailed now always ON.
  * Added service-side Debug Interface implementation.
  * Added service-side Connection ClientTypes interface.
  * Added service-side Connection ContactCapabilities interface.
  * Implemented service-side FileTransfer Interface:
  - Well documented and covered with tests!
  - Supports IPv4 and IPv6 socket types with localhost access control.
  - Supports custom sockets and access control.
  * Added IODevice class, which is interesting for all CMs that have
    backend, that accepts a QIODevice for file transfers.
  * Other improvements.
  - API changes:
  * Service-side of ChannelGroup Interface redone with different API.
  - Fixes:
  * Fixed build with glibc-2.20+
  * Fixed build with GStreamer-1.5.1+
  * Added missing link to QtTest in tests.
  * Added missing link to glib2 in Farstream.
  * Fixed hash calculation of QList<ChannelClassSpec> for Qt-5.6.
  * fd.o #91659: CMake now search for Python 2, rather than Python 3.
  * fd.o #95376: Removed usage of deprecated QDBusArgument stream operators
    (fixes build with Qt-5.7 beta and (probably) Qt-5.8+).
  * fd.o #65981: Fixed build with Ninja (cmake).
  * Fixed memory leak in DBusError.
  * Fixed BaseConnection::createChannel() ".Requested" property processing.
  * Fixed BaseChannelGroupInterface::removeMembers().
  * Fixed BaseChannelGroupInterface::groupFlagsChanged() signal emission.
  * Fixed CreationTimestamp property in BaseChannelRoomInterface.
  * Fixed device management in IncomingFileTransferChannel.
  * Fixed device management in OutgoingFileTransferChannel.
  * BaseConnection now properly closes channels on disconnect.
  * BaseConnection and BaseChannel debug output now respects Tp::enableDebug().
  * Other small fixes.
- removed obsolete patch telepathy-qt5-gst-1_6.patch, now included upstream
- set minimum required cmake version to 2.8.12
* Mon Jan 11 2016 mlin@suse.com
- Do not require libtelepathy-qt5-farstream if it does not build
* Sun Jan 10 2016 mlin@suse.com
- Partial revert the last commit, do not disable the farstream subpackage
  for ppc64le on all version, just disabled it on SLE12.
* Tue Dec 22 2015 alarrosa@suse.com
- Disable the farstream subpackage for ppc64le, since SLE12 doesn't have
  farstream packages in that architecture
* Sun Nov 29 2015 zaitor@opensuse.org
- Update to version 0.9.6.1:
  + Fixed illegal C++ statement in one of service interfaces.
- Add telepathy-qt5-gst-1_6.patch: Fix build with gstreamer-1.6.
* Tue May 19 2015 hrvoje.senjan@gmail.com
- Update to 0.9.6:
  - Enhancements:
  * Added TP_QT_VERSION and TP_QT_VERSION_CHECK macros
  - Can be used like #if (TP_QT_VERSION == TP_QT_VERSION_CHECK(0, 9, 6))
  - Absence of the TP_QT_VERSION macros indicates previous versions
    (might be useful for service bindings compatibility)
  * Added client side support for conference calls
  * Implemented numerous interfaces for service bindings
  - API changes:
  * Refactored service-side bindings API
  - BaseConnection createChannel() and ensureChannel() methods
    now accept request map instead of several extracted values.
  - BaseChannel::create() arguments reordered in natural way.
  - Fixes:
  * Fixed CallContent interfaces exposing (required for DTMF)
  * fd0#86312: Fixed condition in adaptor methods generation
- Drop patches merged upstream:
  Add-missing-QObject-include.patch and add-the-telepathy-qt-include.patch
* Sun Mar 29 2015 hrvoje.senjan@gmail.com
- Add-missing-QObject-include.patch: fixed build with Qt 5.5
* Mon Dec 15 2014 hrvoje.senjan@gmail.com
- Added add-the-telepathy-qt-include.patch
* Tue Sep  9 2014 hrvoje.senjan@gmail.com
- Update to 0.9.5:
  * Added more service side bindings
  * Service bindings now enabled by default
  * Bump Farstream version
  * Allow subclass of Tp::ReceivedMessage
  * Workaround invalid channelRequests when delegating, fdo#77986
- Drop search-for-gstreamer1.0.diff and search-for-farstream0.2.diff,
  merged upstream
- Provide telepathy-qt5-service-devel-static, due to newly enabled
  service library
* Thu Jul 31 2014 hrvoje.senjan@gmail.com
- Move to gstreamer 1.0 API for Factory
- Drop search-for-telepathy-farstream-0.4.diff (support for older
  openSUSE versions is dropped)
- Adjust baselibs.conf for new subpackage
- Update descriptions
* Mon Jun 16 2014 hrvoje.senjan@gmail.com
- Update to 0.9.4
  + Enhancements:
  * fdo#63098: add method Account::createDbusTubeRoom
  + Fixes:
  * fdo#46241: Fixed linking in farstream and farsight
  * Require tp-glib 0.18 and fix 0.19-ism
  * fdo#47647: Fixed storing avatars, so that they are not stored
    millions of times each.
  * fdo#62711: Fixed stack overflow in SimpleObserver::create
  * Fix compilation and running against release Qt5
- Drop patches included in this release:
    0012-Fix-warning-in-DBusTubeChannel.patch
    0035-Fix-ChannelDispatcher.Messages-test.patch
    0031-Update-to-spec-0.27.3.patch
    0026-Fix-tests-build-for-Qt5-release.patch
    0021-account-add-method-Account-createDbusTubeRoom.patch
    0036-Fix-moc-command-for-Qt5.2.patch
    0030-Fix-HandledChannelNotifier-for-Qt5.patch
    0007-Link-telepathy-qt4-farsight-against-gobject.patch
    0005-Start-0.9.4-development.patch
    0039-Add-Q_UNUSED-as-Q_ASSERT-is-a-no-op-in-release-mode.patch
    0025-Fix-build-for-Qt5-release.patch
    0010-cmake-Require-tp-glib-0.18.patch
    0006-farsight-Fix-linking.patch
    0029-Fix-TestDBusProxyFactory-testDropRefs.patch
    0009-glib-Disable-tp_tests_connection_run_until_contact_b.patch
    0028-Fix-TestAccountSet-testFilters.patch
    0038-Allow-compilation-when-only-qmake-qt4-is-in-the-path.patch
    0023-Kill-the-last-bits-of-Farsight.patch
    0027-Fix-TestKeyFile-sort-list-before-comparing.patch
    0018-tests-sync-simple-channel-dispatch-operation.c-from-.patch
    0040-Add-5-to-pkg-config-package-names-for-Qt5.patch
    0037-Simplify-FindQt5.cmake.patch
    0032-Update-changes-from-Channel_Dispatcher_Future.patch
    0034-Add-Room-Subject-RoomConfig-interfaces-to-generation.patch
    0015-Fix-stack-overflow-in-SimpleObserver-create.patch
    0024-Fix-compilation-on-new-versions-of-cmake.patch
    0017-Remove-references-to-deprecated-tp_channel_borrow_im.patch
    0013-Fix-storing-avatars-so-that-they-are-not-stored-mill.patch
    0019-Removing-old-Farsight-files.patch
    0033-Update-test-library-to-match-spec-changes.patch
- Simplify cmake usage during %%build phase
* Mon Jun  2 2014 hrvoje.senjan@gmail.com
- Add baselibs.conf
* Sun Apr 13 2014 hrvoje.senjan@gmail.com
- Activate telepathy-qt5 package
